Bibliography
============


.. [Jähn_et_al_2020] 
    An online emission module for atmospheric chemistry transport models: implementation in COSMO-GHG v5.6a and COSMO-ART v5.1-3.1

    Jähn et al., Geosci. Model Dev., 13, 2379–2392, 2020

    https://doi.org/10.5194/gmd-13-2379-2020.

.. [Mahadevan_2008]
    A satellite-based biosphere parameterization for net ecosystem CO2 exchange: Vegetation Photosynthesis and Respiration Model (VPRM)

    Mahadevan, Pathmathevan and Wofsy, Steven C. and Matross, Daniel M. and Xiao, Xiangming and Dunn, Allison L. and Lin, John C. and Gerbig, Christoph and Munger, J. William and Chow, Victoria Y. and Gottlieb, Elaine W.
    Global Biogeochemical Cycles, 22, 2008

    https://doi.org/10.1029/2006GB002735

.. [Urban_VPRM]
    Quantification of Urban Forest and Grassland Carbon Fluxes Using Field Measurements and a Satellite-Based Model in Washington DC/Baltimore Area

    Winbourne, J. B. and Smith, I. A. and Stoynova, H. and Kohler, C. and Gately, C. K. and Logan, B. A. and Reblin, J. and Reinmann, A. and Allen, D. W. and Hutyra, L. R.
    Journal of Geophysical Research: Biogeosciences, 127, 2022

    https://doi.org/10.1029/2021JG006568